# About ancp-bids
A Python package which allows to:

- read/write
- query
- validate

BIDS datasets using the **BIDS Schema** as its foundation.

# Current state and further reading
We are in a proposal/experimental stage and design decisions may change frequently.
You can follow the progress of the proposal in the following slides:

https://docs.google.com/presentation/d/12x3cQGRD9-T1bkpK--t0e_OdgMb3UuO4jn5fGpj0a4w
